==> aws-cdk-scala-cloudtrail_3-0.1.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"cloudtrail","t":"cloudtrail","d":"","k":"static"},
{"l":"io/burkard/cdk/services/cloudtrail.html","n":"io.burkard.cdk.services.cloudtrail","t":"package io.burkard.cdk.services.cloudtrail","d":"io/burkard/cdk/services/cloudtrail","k":"package"},
{"l":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$.html","n":"AddEventSelectorOptions","t":"object AddEventSelectorOptions","d":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$.html","n":"apply","t":"def apply(readWriteType: Option[ReadWriteType], excludeManagementEventSources: Option[List[_ <: ManagementEventSources]], includeManagementEvents: Option[Boolean]): AddEventSelectorOptions","d":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrail$.html","n":"CfnTrail","t":"object CfnTrail","d":"io/burkard/cdk/services/cloudtrail/CfnTrail$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrail$.html","n":"apply","t":"def apply(internalResourceId: String, includeGlobalServiceEvents: Option[Boolean], insightSelectors: Option[List[_]], tags: Option[List[_ <: CfnTag]], isOrganizationTrail: Option[Boolean], cloudWatchLogsLogGroupArn: Option[String], s3BucketName: Option[String], eventSelectors: Option[List[_]], kmsKeyId: Option[String], cloudWatchLogsRoleArn: Option[String], isLogging: Option[Boolean], s3KeyPrefix: Option[String], isMultiRegionTrail: Option[Boolean], enableLogFileValidation: Option[Boolean], trailName: Option[String], snsTopicName: Option[String])(implicit stackCtx: Stack): CfnTrail","d":"io/burkard/cdk/services/cloudtrail/CfnTrail$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$.html","n":"CfnTrailProps","t":"object CfnTrailProps","d":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$.html","n":"apply","t":"def apply(includeGlobalServiceEvents: Option[Boolean], insightSelectors: Option[List[_]], tags: Option[List[_ <: CfnTag]], isOrganizationTrail: Option[Boolean], cloudWatchLogsLogGroupArn: Option[String], s3BucketName: Option[String], eventSelectors: Option[List[_]], kmsKeyId: Option[String], cloudWatchLogsRoleArn: Option[String], isLogging: Option[Boolean], s3KeyPrefix: Option[String], isMultiRegionTrail: Option[Boolean], enableLogFileValidation: Option[Boolean], trailName: Option[String], snsTopicName: Option[String]): CfnTrailProps","d":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$.html","n":"DataResourceProperty","t":"object DataResourceProperty","d":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$.html","n":"apply","t":"def apply(values: Option[List[String]], `type`: Option[String]): DataResourceProperty","d":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType.html","n":"DataResourceType","t":"class DataResourceType(val underlying: DataResourceType) extends Product with Serializable","d":"io/burkard/cdk/services/cloudtrail/DataResourceType","k":"class"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType.html","n":"underlying","t":"val underlying: DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType","k":"val"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$.html","n":"DataResourceType","t":"object DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$.html","n":"toAws","t":"def toAws(value: DataResourceType): DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$$LambdaFunction$.html","n":"LambdaFunction","t":"object LambdaFunction extends DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$$LambdaFunction$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$$S3Object$.html","n":"S3Object","t":"object S3Object extends DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$$S3Object$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$.html","n":"EventSelectorProperty","t":"object EventSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$.html","n":"apply","t":"def apply(readWriteType: Option[String], dataResources: Option[List[_]], excludeManagementEventSources: Option[List[String]], includeManagementEvents: Option[Boolean]): EventSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$.html","n":"InsightSelectorProperty","t":"object InsightSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$.html","n":"apply","t":"def apply(insightType: Option[String]): InsightSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources.html","n":"ManagementEventSources","t":"class ManagementEventSources(val underlying: ManagementEventSources) extends Product with Serializable","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources","k":"class"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources.html","n":"underlying","t":"val underlying: ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources","k":"val"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$.html","n":"ManagementEventSources","t":"object ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$.html","n":"toAws","t":"def toAws(value: ManagementEventSources): ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$Kms$.html","n":"Kms","t":"object Kms extends ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$Kms$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$RdsDataApi$.html","n":"RdsDataApi","t":"object RdsDataApi extends ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$RdsDataApi$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType.html","n":"ReadWriteType","t":"class ReadWriteType(val underlying: ReadWriteType) extends Product with Serializable","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType","k":"class"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType.html","n":"underlying","t":"val underlying: ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType","k":"val"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$.html","n":"ReadWriteType","t":"object ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$.html","n":"toAws","t":"def toAws(value: ReadWriteType): ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$All$.html","n":"All","t":"object All extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$All$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$None$.html","n":"None","t":"object None extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$None$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$ReadOnly$.html","n":"ReadOnly","t":"object ReadOnly extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$ReadOnly$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$WriteOnly$.html","n":"WriteOnly","t":"object WriteOnly extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$WriteOnly$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/S3EventSelector$.html","n":"S3EventSelector","t":"object S3EventSelector","d":"io/burkard/cdk/services/cloudtrail/S3EventSelector$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/S3EventSelector$.html","n":"apply","t":"def apply(objectPrefix: Option[String], bucket: Option[IBucket]): S3EventSelector","d":"io/burkard/cdk/services/cloudtrail/S3EventSelector$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/Trail$.html","n":"Trail","t":"object Trail","d":"io/burkard/cdk/services/cloudtrail/Trail$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/Trail$.html","n":"apply","t":"def apply(internalResourceId: String, kmsKey: Option[IKey], enableFileValidation: Option[Boolean], cloudWatchLogGroup: Option[ILogGroup], snsTopic: Option[ITopic], bucket: Option[IBucket], encryptionKey: Option[IKey], s3KeyPrefix: Option[String], includeGlobalServiceEvents: Option[Boolean], cloudWatchLogsRetention: Option[RetentionDays], isMultiRegionTrail: Option[Boolean], trailName: Option[String], sendToCloudWatchLogs: Option[Boolean], managementEvents: Option[ReadWriteType])(implicit stackCtx: Stack): Trail","d":"io/burkard/cdk/services/cloudtrail/Trail$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/TrailProps$.html","n":"TrailProps","t":"object TrailProps","d":"io/burkard/cdk/services/cloudtrail/TrailProps$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/TrailProps$.html","n":"apply","t":"def apply(kmsKey: Option[IKey], enableFileValidation: Option[Boolean], cloudWatchLogGroup: Option[ILogGroup], snsTopic: Option[ITopic], bucket: Option[IBucket], encryptionKey: Option[IKey], s3KeyPrefix: Option[String], includeGlobalServiceEvents: Option[Boolean], cloudWatchLogsRetention: Option[RetentionDays], isMultiRegionTrail: Option[Boolean], trailName: Option[String], sendToCloudWatchLogs: Option[Boolean], managementEvents: Option[ReadWriteType]): TrailProps","d":"io/burkard/cdk/services/cloudtrail/TrailProps$","k":"def"},
{"l":"docs/index.html","n":"cloudtrail","t":"cloudtrail","d":"","k":"static"}];

==> aws-cdk-scala-cloudtrail_3-0.1.6-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"cloudtrail","t":"cloudtrail","d":"","k":"static"},
{"l":"io/burkard/cdk/services/cloudtrail.html","n":"io.burkard.cdk.services.cloudtrail","t":"package io.burkard.cdk.services.cloudtrail","d":"io/burkard/cdk/services/cloudtrail","k":"package"},
{"l":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$.html","n":"AddEventSelectorOptions","t":"object AddEventSelectorOptions","d":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$.html","n":"apply","t":"def apply(readWriteType: Option[ReadWriteType], excludeManagementEventSources: Option[List[_ <: ManagementEventSources]], includeManagementEvents: Option[Boolean]): AddEventSelectorOptions","d":"io/burkard/cdk/services/cloudtrail/AddEventSelectorOptions$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrail$.html","n":"CfnTrail","t":"object CfnTrail","d":"io/burkard/cdk/services/cloudtrail/CfnTrail$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrail$.html","n":"apply","t":"def apply(internalResourceId: String, s3BucketName: String, isLogging: Boolean, includeGlobalServiceEvents: Option[Boolean], insightSelectors: Option[List[_]], tags: Option[List[_ <: CfnTag]], isOrganizationTrail: Option[Boolean], cloudWatchLogsLogGroupArn: Option[String], eventSelectors: Option[List[_]], kmsKeyId: Option[String], cloudWatchLogsRoleArn: Option[String], s3KeyPrefix: Option[String], isMultiRegionTrail: Option[Boolean], enableLogFileValidation: Option[Boolean], trailName: Option[String], snsTopicName: Option[String])(implicit stackCtx: Stack): CfnTrail","d":"io/burkard/cdk/services/cloudtrail/CfnTrail$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$.html","n":"CfnTrailProps","t":"object CfnTrailProps","d":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$.html","n":"apply","t":"def apply(s3BucketName: String, isLogging: Boolean, includeGlobalServiceEvents: Option[Boolean], insightSelectors: Option[List[_]], tags: Option[List[_ <: CfnTag]], isOrganizationTrail: Option[Boolean], cloudWatchLogsLogGroupArn: Option[String], eventSelectors: Option[List[_]], kmsKeyId: Option[String], cloudWatchLogsRoleArn: Option[String], s3KeyPrefix: Option[String], isMultiRegionTrail: Option[Boolean], enableLogFileValidation: Option[Boolean], trailName: Option[String], snsTopicName: Option[String]): CfnTrailProps","d":"io/burkard/cdk/services/cloudtrail/CfnTrailProps$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$.html","n":"DataResourceProperty","t":"object DataResourceProperty","d":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$.html","n":"apply","t":"def apply(`type`: String, values: Option[List[String]]): DataResourceProperty","d":"io/burkard/cdk/services/cloudtrail/DataResourceProperty$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType.html","n":"DataResourceType","t":"class DataResourceType(val underlying: DataResourceType) extends Product with Serializable","d":"io/burkard/cdk/services/cloudtrail/DataResourceType","k":"class"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType.html","n":"underlying","t":"val underlying: DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType","k":"val"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$.html","n":"DataResourceType","t":"object DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$.html","n":"toAws","t":"def toAws(value: DataResourceType): DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$$LambdaFunction$.html","n":"LambdaFunction","t":"object LambdaFunction extends DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$$LambdaFunction$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/DataResourceType$$S3Object$.html","n":"S3Object","t":"object S3Object extends DataResourceType","d":"io/burkard/cdk/services/cloudtrail/DataResourceType$$S3Object$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$.html","n":"EventSelectorProperty","t":"object EventSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$.html","n":"apply","t":"def apply(readWriteType: Option[String], dataResources: Option[List[_]], excludeManagementEventSources: Option[List[String]], includeManagementEvents: Option[Boolean]): EventSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/EventSelectorProperty$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$.html","n":"InsightSelectorProperty","t":"object InsightSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$.html","n":"apply","t":"def apply(insightType: Option[String]): InsightSelectorProperty","d":"io/burkard/cdk/services/cloudtrail/InsightSelectorProperty$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources.html","n":"ManagementEventSources","t":"class ManagementEventSources(val underlying: ManagementEventSources) extends Product with Serializable","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources","k":"class"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources.html","n":"underlying","t":"val underlying: ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources","k":"val"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$.html","n":"ManagementEventSources","t":"object ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$.html","n":"toAws","t":"def toAws(value: ManagementEventSources): ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$Kms$.html","n":"Kms","t":"object Kms extends ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$Kms$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$RdsDataApi$.html","n":"RdsDataApi","t":"object RdsDataApi extends ManagementEventSources","d":"io/burkard/cdk/services/cloudtrail/ManagementEventSources$$RdsDataApi$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType.html","n":"ReadWriteType","t":"class ReadWriteType(val underlying: ReadWriteType) extends Product with Serializable","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType","k":"class"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType.html","n":"underlying","t":"val underlying: ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType","k":"val"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$.html","n":"ReadWriteType","t":"object ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$.html","n":"toAws","t":"def toAws(value: ReadWriteType): ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$All$.html","n":"All","t":"object All extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$All$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$None$.html","n":"None","t":"object None extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$None$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$ReadOnly$.html","n":"ReadOnly","t":"object ReadOnly extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$ReadOnly$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$WriteOnly$.html","n":"WriteOnly","t":"object WriteOnly extends ReadWriteType","d":"io/burkard/cdk/services/cloudtrail/ReadWriteType$$WriteOnly$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/S3EventSelector$.html","n":"S3EventSelector","t":"object S3EventSelector","d":"io/burkard/cdk/services/cloudtrail/S3EventSelector$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/S3EventSelector$.html","n":"apply","t":"def apply(bucket: IBucket, objectPrefix: Option[String]): S3EventSelector","d":"io/burkard/cdk/services/cloudtrail/S3EventSelector$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/Trail$.html","n":"Trail","t":"object Trail","d":"io/burkard/cdk/services/cloudtrail/Trail$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/Trail$.html","n":"apply","t":"def apply(internalResourceId: String, kmsKey: Option[IKey], enableFileValidation: Option[Boolean], cloudWatchLogGroup: Option[ILogGroup], snsTopic: Option[ITopic], bucket: Option[IBucket], encryptionKey: Option[IKey], s3KeyPrefix: Option[String], includeGlobalServiceEvents: Option[Boolean], cloudWatchLogsRetention: Option[RetentionDays], isMultiRegionTrail: Option[Boolean], trailName: Option[String], sendToCloudWatchLogs: Option[Boolean], managementEvents: Option[ReadWriteType])(implicit stackCtx: Stack): Trail","d":"io/burkard/cdk/services/cloudtrail/Trail$","k":"def"},
{"l":"io/burkard/cdk/services/cloudtrail/TrailProps$.html","n":"TrailProps","t":"object TrailProps","d":"io/burkard/cdk/services/cloudtrail/TrailProps$","k":"object"},
{"l":"io/burkard/cdk/services/cloudtrail/TrailProps$.html","n":"apply","t":"def apply(kmsKey: Option[IKey], enableFileValidation: Option[Boolean], cloudWatchLogGroup: Option[ILogGroup], snsTopic: Option[ITopic], bucket: Option[IBucket], encryptionKey: Option[IKey], s3KeyPrefix: Option[String], includeGlobalServiceEvents: Option[Boolean], cloudWatchLogsRetention: Option[RetentionDays], isMultiRegionTrail: Option[Boolean], trailName: Option[String], sendToCloudWatchLogs: Option[Boolean], managementEvents: Option[ReadWriteType]): TrailProps","d":"io/burkard/cdk/services/cloudtrail/TrailProps$","k":"def"},
{"l":"docs/index.html","n":"cloudtrail","t":"cloudtrail","d":"","k":"static"}];
